@@ -18,7 +18,6 @@ import time
 from conductor.conductor import WFClientMgr
 from threading import Thread
 import socket
-
 from enum import Enum
 
 hostname = socket.gethostname()
@@ -33,6 +32,7 @@ class TaskStatus(Enum):
         return str(self.value)
 
 
+
 class ConductorWorker:
     """
     Main class for implementing Conductor Workers
@@ -118,7 +118,7 @@ class ConductorWorker:
                 task['reasonForIncompletion'] = resp['reasonForIncompletion']
             self.taskClient.updateTask(task)
         except Exception as err:
-            print('Error executing task: ' + str(err))
+            print(f'Error executing task: {exec_function.__name__} with error: {str(err)}')
             task['status'] = 'FAILED'
             task['outputData'] = {'error-message' : str(err) }
             self.taskClient.updateTask(task)
@@ -181,4 +181,3 @@ def main():
 
 if __name__ == '__main__':
     main()
-
